==> mx-service-manager_23.11.02.tar.xz: BUILD/translations/mx-service-manager_nb.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>MX Service Manager</source>
        <translation>MX tjenestebehandling</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="156"/>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>&amp;Enable at boot</source>
        <translation>&amp;Slå på ved oppstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>&amp;About...</source>
        <translation>&amp;Om …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>Alt+B</source>
        <translation>Alt + B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="126"/>
        <source>Display help </source>
        <translation>Vis hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>Services enabled at boot</source>
        <translation>Tjenester slått på ved oppstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Services disabled at boot</source>
        <translation>Tjenester slått av ved oppstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>search</source>
        <translation>søk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.cpp" line="138"/>
        <source>&amp;Stop</source>
        <translation>&amp;Stopp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
        <translation>Dette verktøyet lister opp tjenester og bakgrunnsprosesser på dette systemet. Vær forsiktig med å stoppe noe som kan forstyrre en kritisk komponent. La den være i fred hvis du ikke vet hva det er.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>All services</source>
        <translation>Alle tjenester</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>Running services</source>
        <translation>Kjørende tjenester</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <source>Alt+H</source>
        <translation>Alt + H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Quit application</source>
        <translation>Avslutt programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>Alt+N</source>
        <translation>Alt + N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <location filename="../mainwindow.cpp" line="67"/>
        <location filename="../mainwindow.cpp" line="80"/>
        <source>Loading...</source>
        <translation>Laster …</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="61"/>
        <location filename="../mainwindow.cpp" line="334"/>
        <location filename="../mainwindow.cpp" line="341"/>
        <location filename="../mainwindow.cpp" line="363"/>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="62"/>
        <source>Could not determine the init system. This program is supposed to run either with systemd or sysvinit</source>
        <translation>Fant ikke riktig ut av type «init». Dette programmet virker med systemd og sysvinit.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="143"/>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>S&amp;tart</source>
        <translation>S&amp;tart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="149"/>
        <source>&amp;Disable at boot</source>
        <translation>Sl&amp;å av ved oppstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>%1 total services, %2 currently %3running%4</source>
        <translation>%1 tjenester totalt, %2 %3kjører%4 nå</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>%1 %2enabled%3 at boot, but not running</source>
        <translation>%1 %2slått på%3 ved oppstart, men kjører ikke</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Version: </source>
        <translation>Versjon:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Service and daemon manager</source>
        <translation>Behandle tjenester og bakgrunnsprosesser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="321"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Opphavsrett (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>%1 License</source>
        <translation>Lisens for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>Could not enable %1</source>
        <translation>Klarte ikke slå på %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <location filename="../mainwindow.cpp" line="345"/>
        <location filename="../mainwindow.cpp" line="368"/>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>Success</source>
        <translation>Vellykket</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>%1 was enabled at boot time.</source>
        <translation>%1 ble slått på ved oppstart.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="341"/>
        <source>Could not disable %1</source>
        <translation>Klarte ikke slå av %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>%1 was disabled.</source>
        <translation>%1 ble slått av.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>%1 Help</source>
        <translation>Hjelpetekst for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>Could not start %1</source>
        <translation>Klarte ikke starte %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="368"/>
        <source>%1 was started.</source>
        <translation>Startet %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Could not stop %1</source>
        <translation>Klarte ikke stoppe %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>%1 was stopped.</source>
        <translation>Stoppet %1.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Endringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="75"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du er innlogget som root. Vennligst logg ut, og logg inn igjen som en vanlig bruker for å bruke dette programmet.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Dette programmet må kjøres med administratorrettigheter.</translation>
    </message>
    <message>
        <location filename="../service.cpp" line="116"/>
        <source>Could not find service description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-service-manager_25.4.tar.xz: BUILD/translations/mx-service-manager_nb.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>MX Service Manager</source>
        <translation>MX tjenestebehandling</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="153"/>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>&amp;Enable at boot</source>
        <translation>&amp;Slå på ved oppstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>&amp;About...</source>
        <translation>&amp;Om …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="71"/>
        <source>Alt+B</source>
        <translation>Alt + B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Display help </source>
        <translation>Vis hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="128"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Alt+H</source>
        <translation>Alt + H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="166"/>
        <source>Quit application</source>
        <translation>Avslutt programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="175"/>
        <source>Alt+N</source>
        <translation>Alt + N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>&amp;Stop</source>
        <translation>&amp;Stopp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>All services</source>
        <translation>Alle tjenester</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <location filename="../mainwindow.cpp" line="316"/>
        <source>Running services</source>
        <translation>Kjørende tjenester</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Services enabled at boot</source>
        <translation>Tjenester slått på ved oppstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Services disabled at boot</source>
        <translation>Tjenester slått av ved oppstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>search</source>
        <translation>søk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="291"/>
        <location filename="../mainwindow.cpp" line="68"/>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Loading...</source>
        <translation>Laster …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
        <translation>Dette verktøyet lister opp tjenester og bakgrunnsprosesser på dette systemet. Vær forsiktig med å stoppe noe som kan forstyrre en kritisk komponent. La den være i fred hvis du ikke vet hva det er.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="62"/>
        <location filename="../mainwindow.cpp" line="388"/>
        <location filename="../mainwindow.cpp" line="395"/>
        <location filename="../mainwindow.cpp" line="416"/>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="63"/>
        <source>Could not determine the init system. This program is supposed to run either with systemd or sysvinit</source>
        <translation>Fant ikke riktig ut av type «init». Dette programmet virker med systemd og sysvinit.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="140"/>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>S&amp;tart</source>
        <translation>S&amp;tart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="146"/>
        <source>&amp;Disable at boot</source>
        <translation>Sl&amp;å av ved oppstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
        <translation>%1 tjenester totalt, %2 &lt;font color=&apos;%3&apos;&gt;kjører nå&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>%1 &lt;font color=&apos;%2&apos;&gt;enabled&lt;/font&gt; at boot, but not running</source>
        <translation>%1 &lt;font color=&apos;%2&apos;&gt;slått på&lt;/font&gt; ved oppstart, men kjører ikke</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Version: </source>
        <translation>Versjon:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="373"/>
        <source>Service and daemon manager</source>
        <translation>Behandle tjenester og bakgrunnsprosesser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Opphavsrett (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>%1 License</source>
        <translation>Lisens for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>Could not enable %1</source>
        <translation>Klarte ikke slå på %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <location filename="../mainwindow.cpp" line="399"/>
        <location filename="../mainwindow.cpp" line="421"/>
        <location filename="../mainwindow.cpp" line="430"/>
        <source>Success</source>
        <translation>Vellykket</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>%1 was enabled at boot time.</source>
        <translation>%1 ble slått på ved oppstart.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>Could not disable %1</source>
        <translation>Klarte ikke slå av %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>%1 was disabled.</source>
        <translation>%1 ble slått av.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="406"/>
        <source>%1 Help</source>
        <translation>Hjelpetekst for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="416"/>
        <source>Could not start %1</source>
        <translation>Klarte ikke starte %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>%1 was started.</source>
        <translation>Startet %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Could not stop %1</source>
        <translation>Klarte ikke stoppe %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="430"/>
        <source>%1 was stopped.</source>
        <translation>Stoppet %1.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Endringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du er innlogget som root. Vennligst logg ut, og logg inn igjen som en vanlig bruker for å bruke dette programmet.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Dette programmet må kjøres med administratorrettigheter.</translation>
    </message>
    <message>
        <location filename="../service.cpp" line="124"/>
        <source>Could not find service description</source>
        <translation>Fant ikke tjenestebeskrivelsen</translation>
    </message>
</context>
</TS>
